@@ -1,7 +1,7 @@
 /* -*- Mode:C; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
 /*
  * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2 as
+ * it under the terms of the GNU General Public License version 3 as
  * published by the Free Software Foundation;
  *
  * This program is distributed in the hope that it will be useful,
@@ -22,8 +22,8 @@
  l_int32 main(l_int32 argc,l_char *argv[])
 {
 	if(argc != 1)
-		l_stderr("usage: ragnutools");
+		l_std_err("usage: ragnutools");
 	else
-		l_stdout("Author:Guastella Marco alias vasta\nhome page:http://www.ragnu.it\ncontact:vasta@ragnu.it\nversion:%s\n",VERSION);
+		l_std_out("Author:Guastella Marco alias vasta\nhome page:http://www.ragnu.it\ncontact:vasta@ragnu.it\nversion:%s\nlicence:GPL3\n",VERSION);
 	return 0;
 }
